==> foundation-2.7.1.tgz: package/PageSearch/PageSearch.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var PageSearch = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M89.307 12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73H54.701L28.752 32.7v5.237h.014a1.724 1.724 0 001.716 1.588h6.49c.907 0 1.642-.7 1.716-1.588h.021V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707H79.35v66.587H38.708v-3.012h-.007a1.73 1.73 0 00-1.73-1.728h-6.49a1.73 1.73 0 00-1.73 1.728v11.239c0 .956.774 1.73 1.73 1.73H87.57a1.73 1.73 0 001.73-1.73v-2.448h.005l.002-76.573z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M49.6 59.04c0-8.847-7.169-16.021-16.02-16.021-8.851 0-16.02 7.174-16.02 16.021 0 2.99.834 5.78 2.26 8.175l-7.815 7.815.031.031a4.38 4.38 0 00-1.344 3.194c0 2.463 1.962 4.39 4.423 4.39a4.427 4.427 0 003.181-1.324l.022.022 8.024-8.024a15.933 15.933 0 007.238 1.741c8.851-.001 16.02-7.173 16.02-16.02zm-25.318-.001a9.298 9.298 0 019.299-9.298 9.297 9.297 0 019.298 9.298 9.297 9.297 0 01-9.298 9.299 9.297 9.297 0 01-9.299-9.299z"
  }));
});
PageSearch.displayName = 'PageSearch';
export var PageSearchDimensions = {
  height: 100,
  width: 100
};

==> foundation-10.15.1.tgz: package/PageSearch/PageSearch.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var PageSearch = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M89.307 12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73H54.701L28.752 32.7v5.237h.014a1.724 1.724 0 001.716 1.588h6.49c.907 0 1.642-.7 1.716-1.588h.021V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707H79.35v66.587H38.708v-3.012h-.007a1.73 1.73 0 00-1.73-1.728h-6.49a1.73 1.73 0 00-1.73 1.728v11.239c0 .956.774 1.73 1.73 1.73H87.57a1.73 1.73 0 001.73-1.73v-2.448h.005l.002-76.573z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M49.6 59.04c0-8.847-7.169-16.021-16.02-16.021-8.851 0-16.02 7.174-16.02 16.021 0 2.99.834 5.78 2.26 8.175l-7.815 7.815.031.031a4.38 4.38 0 00-1.344 3.194c0 2.463 1.962 4.39 4.423 4.39a4.427 4.427 0 003.181-1.324l.022.022 8.024-8.024a15.933 15.933 0 007.238 1.741c8.851-.001 16.02-7.173 16.02-16.02zm-25.318-.001a9.298 9.298 0 019.299-9.298 9.297 9.297 0 019.298 9.298 9.297 9.297 0 01-9.298 9.299 9.297 9.297 0 01-9.299-9.299z"
  }));
});
PageSearch.displayName = 'PageSearch';
export var PageSearchDimensions = {
  height: 100,
  width: 100
};
